Struct RainLanguageServices

pub struct RainLanguageServices { /* private fields */ }
Provides methods for getting language services (such as diagnostics, completion, etc) for a given TextDocumentItem or a RainDocument. Each instance is linked to a shared locked Store instance Arc<RwLock<Store>> that holds all the required metadata/functionalities that are required during parsing a text.

Position encodings provided by the client are irrevelant as RainDocument/Rainlang supports only ASCII characters (parsing will stop at very first encountered non-ASCII character), so any position encodings will result in the same LSP provided Position value which is 1 for each char.

Example

use std::sync::{Arc, RwLock};
use dotrain_lsp::{
    RainLanguageServices, 
    LanguageServiceParams, 
    dotrain::Store, 
    lsp_types::{TextDocumentItem, MarkupKind, Position, Url}
};

// instaniate a shared locked Store
let meta_store = Arc::new(RwLock::new(Store::default()));

// create instatiation params
let params = LanguageServiceParams {
    meta_store: Some(meta_store)
};

// create a new instane with a shared locked Store that is used for all
// parsings that are triggered through available methods of this instance
let lang_services = RainLanguageServices::new(&params);

let text_document = TextDocumentItem {
    uri: Url::parse("file:///example.rain").unwrap(),
    text: "some .rain text content".to_string(),
    version: 0,
    language_id: "rainlang".to_string()
};

// create a new RainDocument instance
let rain_document = lang_services.new_rain_document(&text_document, None);

// get LSP Diagnostics for a given TextDocumentItem
let diagnostics_related_information = true;
let diagnostics = lang_services.do_validate(&text_document, diagnostics_related_information, None);

let position = Position {
    line: 0,
    character: 10
};
let content_format = Some(MarkupKind::PlainText);
let hover = lang_services.do_hover(&text_document, position, content_format, None);

Implementations

Source

impl RainLanguageServices

pub fn js_meta_store(&self) -> MetaStore

The meta Store associated with this RainLanguageServices instance

pub fn js_new(meta_store: &MetaStore) -> RainLanguageServices

Instantiates with the given MetaStore

pub fn js_new_rain_document( &self, text_document: TextDocumentItem, rebinds: Option<Vec<Rebind>>, ) -> RainDocument

Instantiates a RainDocument with remote meta search disabled when parsing from the given TextDocumentItem

pub async fn js_new_rain_document_async( &self, text_document: TextDocumentItem, rebinds: Option<Vec<Rebind>>, ) -> RainDocument

Instantiates a RainDocument with remote meta search enabled when parsing from the given TextDocumentItem

pub fn js_do_validate( &self, text_document: TextDocumentItem, related_information: bool, rebinds: Option<Vec<Rebind>>, ) -> Vec<Diagnostic>

Validates the document with remote meta search disabled when parsing and reports LSP diagnostics

pub fn js_do_validate_rain_document( &self, rain_document: &RainDocument, uri: &str, related_information: bool, ) -> Vec<Diagnostic>

Reports LSP diagnostics from RainDocument’s all problems

pub async fn js_do_validate_async( &self, text_document: TextDocumentItem, related_information: bool, rebinds: Option<Vec<Rebind>>, ) -> JsValue

Validates the document with remote meta search enabled when parsing and reports LSP diagnostics

pub fn js_do_complete( &self, text_document: TextDocumentItem, position: Position, documentation_format: Option<MarkupKind>, rebinds: Option<Vec<Rebind>>, ) -> Option<Vec<CompletionItem>>

Provides completion items at the given position

pub fn js_do_complete_rain_document( &self, rain_document: &RainDocument, uri: &str, position: Position, documentation_format: Option<MarkupKind>, ) -> Option<Vec<CompletionItem>>

Provides completion items at the given position

pub fn js_do_hover( &self, text_document: TextDocumentItem, position: Position, content_format: Option<MarkupKind>, rebinds: Option<Vec<Rebind>>, ) -> Option<Hover>

Provides hover for a fragment at the given position

pub fn js_do_hover_rain_document( &self, rain_document: &RainDocument, position: Position, content_format: Option<MarkupKind>, ) -> Option<Hover>

Provides hover for a RainDocument fragment at the given position

pub fn js_semantic_tokens( &self, text_document: TextDocumentItem, semantic_token_types_index: u32, semantic_token_modifiers_len: usize, rebinds: Option<Vec<Rebind>>, ) -> SemanticTokensPartialResult

Provides semantic tokens for elided fragments

pub fn js_rain_document_semantic_tokens( &self, rain_document: &RainDocument, semantic_token_types_index: u32, semantic_token_modifiers_len: usize, ) -> SemanticTokensPartialResult

Provides semantic tokens for RainDocument’s elided fragments

Source

impl RainLanguageServices

pub fn meta_store(&self) -> Arc<RwLock<Store>>

The meta Store associated with this RainLanguageServices instance

pub fn new(language_params: &LanguageServiceParams) -> RainLanguageServices

Instantiates from the given params

pub fn new_rain_document( &self, text_document: &TextDocumentItem, rebinds: Option<Vec<Rebind>>, ) -> RainDocument

Instantiates a RainDocument with remote meta search disabled when parsing from the given TextDocumentItem

pub async fn new_rain_document_async( &self, text_document: &TextDocumentItem, rebinds: Option<Vec<Rebind>>, ) -> RainDocument

Instantiates a RainDocument with remote meta search enabled when parsing from the given TextDocumentItem

pub fn do_validate( &self, text_document: &TextDocumentItem, related_information: bool, rebinds: Option<Vec<Rebind>>, ) -> Vec<Diagnostic>

Validates the document with remote meta search disabled when parsing and reports LSP diagnostics

pub async fn do_validate_async( &self, text_document: &TextDocumentItem, related_information: bool, rebinds: Option<Vec<Rebind>>, ) -> Vec<Diagnostic>

Validates the document with remote meta search enabled when parsing and reports LSP diagnostics

pub fn do_validate_rain_document( &self, rain_document: &RainDocument, uri: &Url, related_information: bool, ) -> Vec<Diagnostic>

Reports LSP diagnostics from RainDocument’s all problems

pub fn do_complete( &self, text_document: &TextDocumentItem, position: Position, documentation_format: Option<MarkupKind>, rebinds: Option<Vec<Rebind>>, ) -> Option<Vec<CompletionItem>>

Provides completion items at the given position

pub fn do_complete_rain_document( &self, rain_document: &RainDocument, uri: &Url, position: Position, documentation_format: Option<MarkupKind>, ) -> Option<Vec<CompletionItem>>

Provides completion items at the given position

pub fn do_hover( &self, text_document: &TextDocumentItem, position: Position, content_format: Option<MarkupKind>, rebinds: Option<Vec<Rebind>>, ) -> Option<Hover>

Provides hover for a fragment at the given position

pub fn do_hover_rain_document( &self, rain_document: &RainDocument, position: Position, content_format: Option<MarkupKind>, ) -> Option<Hover>

Provides hover for a RainDocument fragment at the given position

pub fn semantic_tokens( &self, text_document: &TextDocumentItem, semantic_token_types_index: u32, semantic_token_modifiers_len: usize, rebinds: Option<Vec<Rebind>>, ) -> SemanticTokensPartialResult

Provides semantic tokens for elided fragments

pub fn rain_document_semantic_tokens( &self, rain_document: &RainDocument, semantic_token_types_index: u32, semantic_token_modifiers_len: usize, ) -> SemanticTokensPartialResult

Provides semantic tokens for RainDocument’s elided fragments